@@ -6,8 +6,8 @@
 ;; Author: Phil Hagelberg, Cornelius Mika, Campbell Barton
 ;; Maintainer: Campbell Barton <ideasman42@gmail.com>
 ;; URL: https://codeberg.org/ideasman42/emacs-idle-highlight-mode
-;; Package-Version: 20250922.1330
-;; Package-Revision: 6fa320d2cc67
+;; Package-Version: 20251030.2359
+;; Package-Revision: e3f16de93ece
 ;; Created: 2008-05-13
 ;; Keywords: convenience
 ;; EmacsWiki: IdleHighlight
@@ -50,7 +50,8 @@
   :group 'faces)
 
 (defface idle-highlight '((t (:inherit region)))
-  "Face used to highlight other occurrences of the word at point.")
+  "Face used to highlight other occurrences of the word at point."
+  :group 'idle-highlight)
 
 (defcustom idle-highlight-exceptions nil
   "List of words to be excepted from highlighting."
